@@ -11,10 +11,11 @@ loggers, filters, and handlers that your application has configured::
     >>> logging.getLogger('x.c')
     >>> from logging_tree import printout
     >>> printout()
-       ""
+    <--""
        Level WARNING
        |
        o<--"a"
+       |   Level NOTSET so inherits level WARNING
        |   |
        |   o<--"a.b"
        |       Level DEBUG
@@ -22,6 +23,7 @@ loggers, filters, and handlers that your application has configured::
        o<--[x]
            |
            o<--"x.c"
+               Level NOTSET so inherits level WARNING
 
 The logger tree should always print successfully, no matter how
 complicated.  A node whose ``[name]`` is in square brackets is a "place
@@ -75,6 +77,12 @@ On older versions of Python you will instead have to install
 Changelog
 ---------
 
+**Version 1.3** - 2013 October 29
+    Be explicit and display the logger level ``NOTSET`` along with the
+    effective level inherited from the logger's ancestors; and display
+    the list of ``.filters`` of a custom logging handler even though it
+    might contain custom code that ignores them.
+
 **Version 1.2** - 2013 January 19
     Compatible with Python 3.3 thanks to @ralphbean.
 
@@ -92,7 +100,7 @@ Changelog
     Initial release.
 
 """
-__version__ = '1.2'
+__version__ = '1.3'
 __all__ = ('tree', 'printout')
 
 from logging_tree.nodes import tree
