@@ -48,7 +48,10 @@ def describe(node):
         name = '"%s"' % node[0]
     yield arrow + name
     if not is_placeholder:
-        if logger.level:
+        if logger.level == logging.NOTSET:
+            yield '   Level NOTSET so inherits level ' + logging.getLevelName(
+                logger.getEffectiveLevel())
+        else:
             yield '   Level ' + logging.getLevelName(logger.level)
         if not logger.propagate:
             yield '   Propagate OFF'
@@ -123,12 +126,12 @@ def describe_handler(h):
     format = handler_formats.get(t)
     if format is not None:
         yield format % h.__dict__
-        for f in getattr(h, 'filters', ()):
-            yield '  Filter %s' % describe_filter(f)
-        if t is logging.handlers.MemoryHandler and h.target is not None:
-            g = describe_handler(h.target)
-            yield '  Handler ' + next(g)
-            for line in g:
-                yield '  ' + line
     else:
         yield repr(h)
+    for f in getattr(h, 'filters', ()):
+        yield '  Filter %s' % describe_filter(f)
+    if t is logging.handlers.MemoryHandler and h.target is not None:
+        g = describe_handler(h.target)
+        yield '  Handler ' + next(g)
+        for line in g:
+            yield '  ' + line
